@@ -18,10 +18,7 @@
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
-#ifdef HAVE_CONFIG_H
-#include <config.h>
-#endif
-
+#include "config.h"
 #include "gedit-bookmarks-plugin.h"
 #include "gedit-bookmarks-app-activatable.h"
 #include "messages/messages.h"
